import React from 'react';
import { FusionConfigurator } from '@equinor/fusion-framework';
import type { AnyModule } from '@equinor/fusion-framework-module';
/**
 * Create a framework provider for react.
 *
 * This function is for providers of framework, like a portal.
 *
 * @param configurator - callback for configuring modules
 * @example
 * ```tsx
 * const config: FusionConfigurator = (config) => {}
 * const Portal = () => {
 *   const Framework = createFrameworkProvider(config);
 *   return (
 *      <Suspense fallback={<span>loading...</span>}>
 *          <Framework>{children}</Framework>
 *      </Suspense>
 *   );
 * };
 * ```
 */
export declare const createFrameworkProvider: <TModules extends Array<AnyModule> = []>(cb: (configurator: FusionConfigurator<TModules>) => void | Promise<void>) => React.LazyExoticComponent<React.FunctionComponent<React.PropsWithChildren<unknown>>>;
